==> org-lsst-ccs-subsystem-power-gui-1.2.2-dev-sources.jar: org/lsst/ccs/subsystem/power/ui/RebPsControlAssembly.java <==
package org.lsst.ccs.subsystem.power.ui;

import java.awt.BorderLayout;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.subsystem.monitor.ui.MonitorAssembly;
import org.lsst.ccs.subsystem.monitor.ui.MonitorGui;
import org.lsst.ccs.subsystem.power.data.RebPsFullState;
import org.lsst.ccs.subsystem.power.data.RebPsState;

/**
 ******************************************************************************
 **
 **  Implements the REB PS control panel / monitor panel assembly.
 **
 **  @author Owen Saxton
 **
 ******************************************************************************
 */
public class RebPsControlAssembly extends MonitorGui.Panel {

    MonitorAssembly mon;
    RebPsControlPanel panel;
    
    public RebPsControlAssembly(RebPsControlGui gui) {
        setLayout(new java.awt.BorderLayout());
        mon = new MonitorAssembly(gui);
        add(mon, BorderLayout.CENTER);
        panel = new RebPsControlPanel(gui);
        add(panel, BorderLayout.SOUTH);
    }

    public void setSubsystems(String... names) {
        mon.setSubsystems(names);
        panel.setSubsystems(names[0]);
    }

    @Override
    public void disableSystem(String name, int id) {
        panel.disableSystem(id);
        mon.disableSystem(name);
    }

    @Override
    public void updatePanel(String name, int id, Object d) {
        if (d instanceof RebPsFullState) {
            RebPsFullState r = (RebPsFullState)d;
            mon.updateTableModel(name, r.getMonitorFullState());
            panel.updateControlPanel(id, r.getRebPsState());
        }
    }

    @Override
    public void handleStatusData(String name, int id, long time, String key,
                                 Object d) {
        if (key.equals(RebPsState.KEY)) {
            panel.updateControlPanel(id, (RebPsState)((KeyValueData)d).getValue());
        }
        else {
            mon.handleData(name, key, d);
        }
    }

    private static final long serialVersionUID = 1L;
}

==> org-lsst-ccs-subsystem-power-gui-1.4.0-sources.jar: org/lsst/ccs/subsystem/power/ui/RebPsControlAssembly.java <==
package org.lsst.ccs.subsystem.power.ui;

import java.awt.BorderLayout;
import org.lsst.ccs.bus.data.KeyValueData;
import org.lsst.ccs.subsystem.monitor.ui.MonitorAssembly;
import org.lsst.ccs.subsystem.monitor.ui.MonitorGui;
import org.lsst.ccs.subsystem.power.data.RebPsFullState;
import org.lsst.ccs.subsystem.power.data.RebPsState;

/**
 *  Implements the REB PS control panel / monitor panel assembly.
 *
 *  @author Owen Saxton
 */
public class RebPsControlAssembly extends MonitorGui.Panel {

    MonitorAssembly mon;
    RebPsControlPanel panel;
    
    public RebPsControlAssembly(RebPsControlGui gui) {
        setLayout(new java.awt.BorderLayout());
        mon = new MonitorAssembly(gui);
        add(mon, BorderLayout.CENTER);
        panel = new RebPsControlPanel(gui);
        add(panel, BorderLayout.SOUTH);
    }

    public void setSubsystems(String... names) {
        mon.setSubsystems(names);
        panel.setSubsystems(names[0]);
    }

    @Override
    public void disableSystem(String name, int id) {
        panel.disableSystem(id);
        mon.disableSystem(name);
    }

    @Override
    public void updatePanel(String name, int id, Object d) {
        if (d instanceof RebPsFullState) {
            RebPsFullState r = (RebPsFullState)d;
            mon.updateTableModel(name, r.getMonitorFullState());
            panel.updateControlPanel(id, r.getRebPsState());
        }
    }

    @Override
    public void handleStatusData(String name, int id, long time, String key,
                                 Object d) {
        if (key.equals(RebPsState.KEY)) {
            panel.updateControlPanel(id, (RebPsState)((KeyValueData)d).getValue());
        }
        else {
            mon.handleData(name, key, d);
        }
    }

    private static final long serialVersionUID = 1L;
}
